@@ -9,8 +9,8 @@ from sklearn.metrics import r2_score, roc_auc_score
 import plotly.graph_objects as go
 import dtreeviz 
 
-from explainerdashboard.explainers import RandomForestRegressionExplainer
-from explainerdashboard.explainers import RandomForestClassifierExplainer
+from explainerdashboard.explainers import RegressionExplainer
+from explainerdashboard.explainers import ClassifierExplainer
 from explainerdashboard.datasets import titanic_survive, titanic_fare, titanic_names
 
 
@@ -23,7 +23,7 @@ class ClassifierBunchTests(unittest.TestCase):
         model = RandomForestClassifier(n_estimators=5, max_depth=2)
         model.fit(X_train, y_train)
 
-        self.explainer = RandomForestClassifierExplainer(
+        self.explainer = ClassifierExplainer(
                             model, X_test, y_test, roc_auc_score, 
                             shap='tree',
                             cats=['Sex', 'Cabin', 'Embarked'],
@@ -36,7 +36,7 @@ class ClassifierBunchTests(unittest.TestCase):
     def test_decision_trees(self):
         dt = self.explainer.decision_trees
         self.assertIsInstance(dt, list)
-        self.assertIsInstance(dt[0], dtreeviz.shadow.ShadowDecTree)
+        self.assertIsInstance(dt[0], dtreeviz.models.shadow_decision_tree.ShadowDecTree)
 
     def test_decisiontree_df(self):
         df = self.explainer.decisiontree_df(tree_idx=0, index=0)
@@ -70,7 +70,7 @@ class RegressionBunchTests(unittest.TestCase):
         model = RandomForestRegressor(n_estimators=5, max_depth=2)
         model.fit(X_train, y_train)
 
-        self.explainer = RandomForestRegressionExplainer(
+        self.explainer = RegressionExplainer(
                             model, X_test, y_test, r2_score, 
                             shap='tree',
                             cats=['Sex', 'Cabin', 'Embarked'],
@@ -82,7 +82,7 @@ class RegressionBunchTests(unittest.TestCase):
     def test_decision_trees(self):
         dt = self.explainer.decision_trees
         self.assertIsInstance(dt, list)
-        self.assertIsInstance(dt[0], dtreeviz.shadow.ShadowDecTree)
+        self.assertIsInstance(dt[0], dtreeviz.models.shadow_decision_tree.ShadowDecTree)
 
     def test_decisiontree_df(self):
         df = self.explainer.decisiontree_df(tree_idx=0, index=0)
